@@ -25,7 +25,9 @@ settings.configure(default_settings=settings_default,
                    },
                    SEND_BACKLINKS=False,
                    JABBER_DEFAULT_HOST=None,
-                   PERMISSIONS_CACHE=False
+                   PERMISSIONS_CACHE=False,
+                   ANONYMOUS_USER_NAME=None,
+                   SERIALIZER_CACHE=False
                    )
 
 django.setup()
